@@ -2,6 +2,7 @@ from config import Config
 import os
 from smms_img import SmmsImg
 from user_exception import UserException
+from download_help import DownloadHelp
 
 
 class Main():
@@ -52,6 +53,18 @@ class Main():
                     localImages.add(content)
                     self.findLocalImageFile(content, localImages)
 
+    def findImagesInStr(self, line: str, localImages: list):
+        '''递归查找某段字符串中中括号包裹的内容是否为本地图片'''
+        linePart = line.partition('(')
+        if len(linePart[2]) > 0:
+            secondPart = linePart[2].partition(')')
+            content = secondPart[0]
+            if len(content) > 0:
+                # print(content)
+                if content.endswith('.png'):
+                    localImages.append(content)
+                    self.findImagesInStr(content, localImages)
+
     def dealMdFile(self, mdFile: str):
         imgDict = dict()
         localImages = set()
@@ -75,6 +88,17 @@ class Main():
                 copyFileOpen.write(line)
         copyFileOpen.close()
 
+    def findImgsInMdFile(self, mdFile):
+        '''查找markdown文件中的图片列表'''
+        localImages = list()
+        # 逐行扫描，查找本地图片
+        with open(file=mdFile, mode='r', encoding='UTF-8') as fopen:
+            for line in fopen:
+                # 去除行尾的换行
+                subLine = line[0:len(line)-1]
+                self.findImagesInStr(subLine, localImages)
+        return localImages
+
     def dealUserException(self, userExp: UserException):
         sysConfig = Config()
         if userExp.getErrorCode() == UserException.CODE_NO_CONFIG:
@@ -92,7 +116,6 @@ class Main():
     def main(self):
         # 检索当前目录中的markdown文件
         for dir in os.listdir():
-            # print(dir)
             if os.path.isfile(dir):
                 if self.isOrigMdFile(dir):
                     # 复制一份拷贝，如果有，则不覆盖
@@ -106,4 +129,43 @@ class Main():
                             self.dealUserException(e)
                         print("已成功处理markdown文件", dir)
         print("所有markdown文档已处理完毕")
-        exit()
+
+    def outputHelpInfo(self):
+        with open(file='help.info', mode='r', encoding='UTF-8') as helpFileOpen:
+            content = helpFileOpen.read()
+            print(content)
+
+    def imgRecovery(self):
+        '''使用图床备份中的图片来修复本地的图片库'''
+        # 检索当前目录的markdown原始文件
+        for dir in os.listdir():
+            if os.path.isfile(dir) and self.isOrigMdFile(dir):
+                copyFilePath = self.getCopyFilePath(dir)
+                if os.path.exists(copyFilePath):
+                    # 如果存在图床备份，进行还原操作
+                    if self.recoveryImgsInMarkdown(copyFilePath, dir):
+                        print("已成功还原markdown文件", dir, "的本地图库")
+        print("所有markdown文档已处理完毕")
+
+    def copyImgFromWeb(self, webImg, localImgPath):
+        if not os.path.exists(localImgPath):
+            downloader = DownloadHelp()
+            downloader.download(webImg, localImgPath)
+
+    def recoveryImgsInMarkdown(self, copyFilePath: 'copied markdown file path', orignalFile: 'orignal markdown file'):
+        '''使用图床图片还原本地图库'''
+        # 读取图床备份图片列表
+        copyImages = self.findImgsInMdFile(copyFilePath)
+        # 读取本地markdown文件原始地址列表
+        orignalImages = self.findImgsInMdFile(orignalFile)
+        # 还原本地图片库
+        if len(copyImages) == len(orignalImages):
+            # 如果图片数目正好对等，处理
+            imgLength = len(copyImages)
+            for i in range(0, imgLength):
+                self.copyImgFromWeb(copyImages[i], orignalImages[i])
+            return True
+        else:
+            # 输出错误信息
+            print('文件', orignalFile, '中的图片数目与备份中的数目不相符，请自行确认')
+            return False
